package extmedias

import (
	"github.com/jmoiron/sqlx"
	"github.com/lib/pq"
	"gitlab.quimbo.fr/odwrtw/canape-sql/src/internal/sqly"
)

const (
	upsertExternalMediaQuery = `
	INSERT INTO external_medias (type, source, category, ids)
	VALUES (:type, :source, :category, :ids)
	ON CONFLICT (type, source, category)
	DO UPDATE SET type=:type, source=:source, category=:category, ids=:ids
	RETURNING id;`

	deleteExternalMediaQuery = `DELETE FROM external_medias WHERE id=:id;`
	getExternalMediaQuery    = `SELECT * FROM external_medias WHERE type=$1 AND source=$2 AND category=$3 LIMIT 1;`
)

// Media represents an external media
type Media struct {
	sqly.BaseModel
	Type     string         `db:"type"`
	Source   string         `db:"source"`
	Category string         `db:"category"`
	IDs      pq.StringArray `db:"ids"`
}

// Upsert adds or updates or adds the Media in the database
func (m *Media) Upsert(db *sqlx.DB) error {
	var id string
	r, err := db.NamedQuery(upsertExternalMediaQuery, m)
	if err != nil {
		return err
	}
	for r.Next() {
		r.Scan(&id)
	}
	m.ID = id
	return nil
}

// Delete the media from database or raise an error
func (m *Media) Delete(db *sqlx.DB) error {
	_, err := db.NamedExec(deleteExternalMediaQuery, m)
	return err
}

// Get gets a media
func Get(db *sqlx.DB, mtype, msrc, mcat string) (*Media, error) {
	m := &Media{}
	if err := db.QueryRowx(getExternalMediaQuery, mtype, msrc, mcat).StructScan(m); err != nil {
		return nil, err
	}

	return m, nil
}
