package sqly

import (
	"os"
	"testing"
	"time"

	"github.com/jmoiron/sqlx"
	"github.com/mattes/migrate/migrate"
)

var migrationPath string

func init() {
	migrationPath = os.Getenv("MIGRATION_PATH")
	if migrationPath == "" {
		migrationPath = "../../../sql/migration"
	}
}

// BaseModel have to be embeded in all your struct which reflect a table
type BaseModel struct {
	ID      string
	Updated time.Time `db:"updated_at"`
	Created time.Time `db:"created_at"`
}

// RunWithLastestMigration runs your test with database migration set to the lastest
func RunWithLastestMigration(db *sqlx.DB, pgdsn string, t *testing.T, test func(db *sqlx.DB, t *testing.T)) {
	defer func() {
		allErrors, ok := migrate.DownSync(pgdsn, migrationPath)
		if !ok {
			for _, err := range allErrors {
				t.Log(err)
				t.Fatal("We get some errors when reset the database schema")
			}
		}
	}()

	allErrors, ok := migrate.UpSync(pgdsn, migrationPath)
	if !ok {
		for _, err := range allErrors {
			t.Log(err)
			t.Fatal("Impossible to run test we get some errors when initialize the database schema")
		}
	}

	test(db, t)
}
