package torrents

import (
	"encoding/json"
	"errors"
	"net/http"

	"gitlab.quimbo.fr/odwrtw/canape-sql/src/internal/auth"
	"gitlab.quimbo.fr/odwrtw/canape-sql/src/internal/config"
	"gitlab.quimbo.fr/odwrtw/canape-sql/src/internal/users"
	"gitlab.quimbo.fr/odwrtw/canape-sql/src/internal/web"

	"github.com/odwrtw/papi"
)

// DownloadHandler downloads a movie via polochon
func DownloadHandler(env *web.Env, w http.ResponseWriter, r *http.Request) error {
	var data struct {
		URL string `json:"url"`
	}
	err := json.NewDecoder(r.Body).Decode(&data)
	if err != nil {
		return env.RenderError(w, errors.New("failed to get the url"))
	}

	if data.URL == "" {
		return env.RenderError(w, errors.New("no given url"))
	}

	v := auth.GetCurrentUser(r, env.Log)
	user, ok := v.(*users.User)
	if !ok {
		return env.RenderError(w, errors.New("invalid user type"))
	}

	var polochonConfig config.UserPolochon
	err = user.GetConfig("polochon", &polochonConfig)
	if err != nil {
		return env.RenderError(w, errors.New("problem when getting user config"))
	}

	client, err := papi.New(polochonConfig.URL)
	if err != nil {
		return env.RenderError(w, errors.New("problem when getting papi client"))
	}

	if polochonConfig.Token != "" {
		client.SetToken(polochonConfig.Token)
	}

	err = client.AddTorrent(data.URL)
	if err != nil {
		return env.RenderError(w, err)
	}

	return env.RenderOK(w, "Torrent added")
}
