import React from 'react'
import { store } from '../store'
import { isUserLoggedIn } from '../actions/actionCreators'

import { Nav, Navbar, NavItem, NavDropdown, MenuItem } from 'react-bootstrap'
import { LinkContainer } from 'react-router-bootstrap'
import { Control, Form } from 'react-redux-form';

export default class NavBar extends React.Component {
  constructor(props) {
    super(props);
    this.handleMovieSearch = this.handleMovieSearch.bind(this);
    this.handleShowSearch = this.handleShowSearch.bind(this);
  }
  handleMovieSearch() {
    this.props.router.push(`/movies/search/${encodeURI(this.props.movieStore.search)}`)
  }
  handleShowSearch() {
    this.props.router.push(`/shows/search/${encodeURI(this.props.showStore.search)}`)
  }
  render() {
    const username = this.props.userStore.username;
    const isLoggedIn = username !== "" ? true : false;
    const location = this.props.router.getCurrentLocation().pathname;
    let displayMovieSearch = false;
    let displayShowSearch = false;
    if (isLoggedIn && location.indexOf("movies") > -1)
    {
      displayMovieSearch = true;
    }
    if (isLoggedIn && location.indexOf("shows") > -1)
    {
      displayShowSearch = true;
    }
    return (
      <div>
        <Navbar fluid fixedTop collapseOnSelect>
          <Navbar.Header>
            <LinkContainer to="/">
              <Navbar.Brand><a href="#">Canapé</a></Navbar.Brand>
            </LinkContainer>
            <Navbar.Toggle />
          </Navbar.Header>
          <Navbar.Collapse>
            <Nav>
              <LinkContainer to="/movies/popular">
                <NavItem>Popular movies</NavItem>
              </LinkContainer>
              <LinkContainer to="/movies/polochon">
                <NavItem>Polochon movies</NavItem>
              </LinkContainer>
              <LinkContainer to="/shows/popular">
                <NavItem>Polochon shows</NavItem>
              </LinkContainer>
            </Nav>
            <Nav pullRight>
              {isLoggedIn ||
                <LinkContainer to="/users/signup">
                  <NavItem>Sign up</NavItem>
                </LinkContainer>
              }
              {isLoggedIn ||
                <LinkContainer to="/users/login">
                  <NavItem>Login</NavItem>
                </LinkContainer>
              }
              {isLoggedIn &&
                  <NavDropdown title={username} id="navbar-dropdown-right">
                    <LinkContainer to="/users/edit">
                      <MenuItem>Edit</MenuItem>
                    </LinkContainer>
                    <LinkContainer to="/users/logout" onClick={this.props.userLogout}>
                      <MenuItem>Logout</MenuItem>
                    </LinkContainer>
                  </NavDropdown>
              }
            </Nav>
            {displayMovieSearch &&
              <Navbar.Form pullRight>
                <Form model="movieStore" className="input-group" onSubmit={() => this.handleMovieSearch()}>
                  <Control.text
                    model="movieStore.search"
                    className="form-control"
                    placeholder="Search movies"
                    updateOn="change"
                  />
                </Form>
              </Navbar.Form>
            }
            {displayShowSearch &&
              <Navbar.Form pullRight>
                <Form model="showStore" className="input-group" onSubmit={() => this.handleShowSearch()}>
                  <Control.text
                    model="showStore.search"
                    className="form-control"
                    placeholder="Search shows"
                    updateOn="change"
                  />
                </Form>
              </Navbar.Form>
            }
          </Navbar.Collapse>
        </Navbar>
      </div>
    );
  }
}
