import React from 'react'
import Loader from '../loader/loader'

export default class ShowDetails extends React.Component {
  componentWillMount() {
    this.props.fetchShowDetails(this.props.params.imdbId);
  }
  render() {
    // Loading
    if (this.props.showStore.loading) {
      return (<Loader />);
    }
    return (
      <div className="row" id="container">
        <Header data={this.props.showStore.show} />
        <SeasonsList
          data={this.props.showStore.show}
          addTorrent={this.props.addTorrent}
        />
      </div>
    );
  }
}

function Header(props){
  return (
    <div className="col-xs-12 col-sm-10 col-sm-offset-1 col-md-10 col-md-offset-1">
      <div className="panel panel-default">
        <div className="panel-body">
          <HeaderThumbnail data={props.data} />
          <HeaderDetails data={props.data} />
        </div>
      </div>
    </div>
  );
}

function HeaderThumbnail(props){
  return (
    <div className="col-xs-12 col-sm-2 text-center">
      <img src={props.data.poster_url}
        className="show-thumbnail thumbnail-selected img-thumbnail img-responsive"/>
    </div>
  );
}

function HeaderDetails(props){
  const imdbLink = `http://www.imdb.com/title/${props.data.imdb_id}`;
  return (
    <div className="col-xs-12 col-sm-10">
      <dl className="dl-horizontal">
        <dt>Title</dt>
        <dd>{props.data.title}</dd>
        <dt>Plot</dt>
        <dd className="plot">{props.data.plot}</dd>
        <dt>IMDB</dt>
        <dd>
          <a type="button" className="btn btn-warning btn-xs" href={imdbLink}>
            <i className="fa fa-external-link"></i> Open in IMDB
          </a>
        </dd>
        <dt>Year</dt>
        <dd>{props.data.year}</dd>
        <dt>Rating</dt>
        <dd>{props.data.rating}</dd>
      </dl>
    </div>
  );
}

function SeasonsList(props){
  return (
    <div>
      {props.data.seasons.length > 0 && props.data.seasons.map(function(season, index) {
        return (
          <div className="col-xs-12 col-sm-10 col-sm-offset-1 col-md-10 col-md-offset-1" key={index}>
            <Season
              data={season}
              addTorrent={props.addTorrent}
            />
          </div>
        )
      })}
    </div>
  )
}

class Season extends React.Component {
  constructor(props) {
    super(props);
    this.handleClick = this.handleClick.bind(this);
    this.state = { colapsed: true };
  }
  handleClick(e) {
    e.preventDefault();
    this.setState({ colapsed: !this.state.colapsed });
  }
  render() {
    return (
      <div className="panel panel-default">
        <div className="panel-heading clickable" onClick={(e) => this.handleClick(e)}>
          Season {this.props.data.season}
          <small className="text-primary"> — ({this.props.data.episodes.length} episodes)</small>
          <span className="pull-right">
            {this.state.colapsed ||
              <i className="fa fa-chevron-down"></i>
            }
            {this.state.colapsed &&
              <i className="fa fa-chevron-left"></i>
            }
          </span>
        </div>
        {this.state.colapsed ||
          <table className="table table-striped">
            <tbody>
              {this.props.data.episodes.map(function(episode, index) {
                let key = `${episode.season}-${episode.episode}`;
                return (
                  <Episode
                    key={key}
                    data={episode}
                    addTorrent={this.props.addTorrent}
                  />
                )
              }, this)}
            </tbody>
          </table>
        }
      </div>
    )
  }
}

function Episode(props) {
  return (
    <tr>
      <th scope="row" className="col-xs-1">{props.data.episode}</th>
      <td className="col-xs-8">{props.data.title}</td>
      <td className="col-xs-3">
        <span className="pull-right">
          {props.data.torrents && props.data.torrents.map(function(torrent, index) {
            let key = `${props.data.season}-${props.data.episode}-${torrent.source}-${torrent.quality}`;
            return (
              <Torrent
                data={torrent}
                key={key}
                addTorrent={props.addTorrent}
              />
            )
          })}
        </span>
      </td>
    </tr>
  )
}

class Torrent extends React.Component {
  constructor(props) {
    super(props);
    this.handleClick = this.handleClick.bind(this);
  }
  handleClick(e, url) {
    e.preventDefault();
    this.props.addTorrent(url);
  }
  render() {
    return (
      <span className="episode-button">
        <a type="button"
          className="btn btn-primary btn-xs"
          onClick={(e) => this.handleClick(e, this.props.data.url)}
          href={this.props.data.url} >
          <i className="fa fa-download"></i> {this.props.data.quality}
        </a>
      </span>
    )
  }
}
